Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS CodeStar.

Actions, resources, and condition keys for AWS CodeStar - Service Authorization Reference

# Actions, resources, and condition keys for AWS CodeStar

AWS CodeStar (service prefix: `codestar` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS CodeStar
- Resource types defined by AWS CodeStar
- Condition keys for AWS CodeStar

## Actions defined by AWS CodeStar

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AssociateTeamMember | Grants permission to add a user to the team for an AWS CodeStar project | Permissions management | project* |  |
CreateProject | Grants permission to create a project with minimal structure, customer policies, and no resources | Permissions management |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateUserProfile | Grants permission to create a profile for a user that includes user preferences, display name, and email | Write | user* |  |
DeleteExtendedAccess [permission only] | Grants permission to extended delete APIs | Write | project* |  |
DeleteProject | Grants permission to delete a project, including project resources. Does not delete users associated with the project, but does delete the IAM roles that allowed access to the project | Permissions management | project* |  |
DeleteUserProfile | Grants permission to delete a user profile in AWS CodeStar, including all personal preference data associated with that profile, such as display name and email address. It does not delete the history of that user, for example the history of commits made by that user | Write | user* |  |
DescribeProject | Grants permission to describe a project and its resources | Read | project* |  |
DescribeUserProfile | Grants permission to describe a user in AWS CodeStar and the user attributes across all projects | Read |  |  |
DisassociateTeamMember | Grants permission to remove a user from a project. Removing a user from a project also removes the IAM policies from that user that allowed access to the project and its resources | Permissions management | project* |  |
GetExtendedAccess [permission only] | Grants permission to extended read APIs | Read | project* |  |
ListProjects | Grants permission to list all projects in CodeStar associated with your AWS account | List |  |  |
ListResources | Grants permission to list all resources associated with a project in CodeStar | List | project* |  |
ListTagsForProject | Grants permission to list the tags associated with a project in CodeStar | List | project* |  |
ListTeamMembers | Grants permission to list all team members associated with a project | List | project* |  |
ListUserProfiles | Grants permission to list user profiles in AWS CodeStar | List |  |  |
PutExtendedAccess [permission only] | Grants permission to extended write APIs | Write | project* |  |
TagProject | Grants permission to add tags to a project in CodeStar | Tagging | project* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagProject | Grants permission to remove tags from a project in CodeStar | Tagging | project* |  |
| aws:TagKeys |
UpdateProject | Grants permission to update a project in CodeStar | Write | project* |  |
UpdateTeamMember | Grants permission to update team member attributes within a CodeStar project | Permissions management | project* |  |
UpdateUserProfile | Grants permission to update a profile for a user that includes user preferences, display name, and email | Write | user* |  |
VerifyServiceRole | Grants permission to verify whether the AWS CodeStar service role exists in the customer's account | List |  |  |

## Resource types defined by AWS CodeStar

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
project | `arn:$ { Partition}:codestar:$ { Region}:$ { Account}:project/$ { ProjectId}` | aws:ResourceTag/${TagKey}
user | `arn:$ { Partition}:iam::$ { Account}:user/$ { AwsUserName}` | iam:ResourceTag/${TagKey}

## Condition keys for AWS CodeStar

AWS CodeStar defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by requests based on the allowed set of values for each of the tags | String
aws:ResourceTag/${TagKey} | Filters access by actions based on tag-value associated with the resource | String
aws:TagKeys | Filters access by requests based on the presence of mandatory tags in the request | ArrayOfString
iam:ResourceTag/${TagKey} | Filters access by actions based on tag-value associated with the resource | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.